@@ -1,4 +1,4 @@
-# Copyright (c) 2012-2021 Trevor L. Davis <trevor.l.davis@gmail.com>
+# Copyright (c) 2012-2024 Trevor L. Davis <trevor.l.davis@gmail.com>
 #
 #  This file is free software: you may copy, redistribute and/or modify it
 #  under the terms of the GNU General Public License as published by the
@@ -22,27 +22,24 @@
 
 #' Create a command line parser
 #'
-#' \code{ArgumentParser} creates a parser object that acts as
-#' a wrapper to Python's argparse module
+#' `ArgumentParser()` creates a parser object that acts as
+#' a wrapper to Python's `argparse` module
 #'
-#' @param ... Arguments cleaned and passed to Pythons argparse.ArgumentParser()
-#' @param python_cmd Python executable for \code{argparse} to use.
-#'      Must have argparse and json modules (automatically included Python 2.7 and 3.2+).
+#' @param ... Arguments cleaned and passed to Pythons `argparse.ArgumentParser()`
+#' @param python_cmd Python executable for `argparse` to use.
+#'      Must have `argparse` and `json` modules (automatically bundled with Python 2.7 and 3.2+).
 #'      If you need Unicode argument support then you must use Python 3.0+.
-#'      Default will be to use \code{findpython} package to find suitable Python binary.
-#' @return  \code{ArgumentParser} returns a parser object which contains
-#'    an \code{add_argument} function to add arguments to the parser,
-#'    a \code{parse_args} function to parse command line arguments into
-#'    a list, a \code{print_help} and \code{print_usage} function to print
+#'      Default will be to use `findpython` package to find suitable Python binary.
+#' @return  `ArgumentParser()` returns a parser object which contains
+#'    an `add_argument()` function to add arguments to the parser,
+#'    a `parse_args()` function to parse command line arguments into
+#'    a list, a `print_help()` and a `print_usage()` function to print
 #'    usage information.  See code examples, package vignette,
 #'    and corresponding python module for more information on how to use it.
 #'
-#' @references Python's \code{argparse} library, which this package is based on,
+#' @references Python's `argparse` library, which this package is based on,
 #'  is described here: \url{https://docs.python.org/3/library/argparse.html}
 #'
-#' @import jsonlite
-#' @import R6
-#' @export
 #' @examples
 #'
 #' if (argparse:::detects_python()) {
@@ -59,6 +56,8 @@
 #'   accumulate_fn <- get(args$accumulate)
 #'   print(accumulate_fn(args$integers))
 #' }
+#' @importFrom R6 R6Class
+#' @export
 ArgumentParser <- function(..., python_cmd = NULL) { # nolint
     python_cmd <- find_python_cmd(python_cmd)
     assert_python_cmd(python_cmd)
@@ -272,7 +271,7 @@ convert_argument <- function(argument, as_list = FALSE) {
 
 convert_character <- function(s) {
     bool <- substr(s, nchar(s), nchar(s)) == '"'
-    ifelse(bool, paste0("'''", s, "'''"), paste0('"""', s, '"""'))
+    ifelse(bool, paste0("r'''", s, "'''"), paste0('r"""', s, '"""'))
 }
 
 get_python_type <- function(type, proposed_arguments) {
@@ -393,6 +392,7 @@ find_python_cmd <- function(python_cmd = NULL) {
             python_cmd <- findpython::find_python_cmd(required_modules = required_modules)
         }
     }
+    python_cmd <- normalizePath(python_cmd, mustWork = FALSE)
     python_cmd
 }
 
